From: mgrac@sourceware.org <mgrac@sourceware.org>
To: cluster-devel.redhat.com
Subject: [Cluster-devel] cluster/rgmanager/src/resources netfs.sh
Date: 3 Oct 2007 16:40:07 -0000 [thread overview]
Message-ID: <20071003164007.25115.qmail@sourceware.org> (raw)
CVSROOT: /cvs/cluster
Module name: cluster
Changes by: mgrac at sourceware.org 2007-10-03 16:40:07
Modified files:
rgmanager/src/resources: netfs.sh
Log message:
Resolves: #250681 - mount samba share from netfs RA
Patches:
http://sourceware.org/cgi-bin/cvsweb.cgi/cluster/rgmanager/src/resources/netfs.sh.diff?cvsroot=cluster&r1=1.9&r2=1.10
--- cluster/rgmanager/src/resources/netfs.sh 2007/05/21 15:58:04 1.9
+++ cluster/rgmanager/src/resources/netfs.sh 2007/10/03 16:40:06 1.10
@@ -21,7 +21,7 @@
#
#
# NFS file system mount/umount/etc. agent
#
LC_ALL=C
@@ -50,10 +50,10 @@
<version>1.0</version>
<longdesc lang="en">
- This defines an NFS mount for use by cluster services.
+ This defines an NFS/CIFS mount for use by cluster services.
</longdesc>
<shortdesc lang="en">
- Defines an NFS file system mount.
+ Defines an NFS/CIFS file system mount.
</shortdesc>
<parameters>
@@ -79,7 +79,7 @@
<parameter name="host" required="1">
<longdesc lang="en">
- NFS Server IP address or hostname
+ Server IP address or hostname
</longdesc>
<shortdesc lang="en">
IP or Host
@@ -89,7 +89,7 @@
<parameter name="export" required="1">
<longdesc lang="en">
- NFS Export directory name
+ NFS Export directory name or CIFS share
</longdesc>
<shortdesc lang="en">
Export
@@ -99,10 +99,10 @@
<parameter name="fstype" required="0">
<longdesc lang="en">
- NFS File System type (nfs or nfs4)
+ File System type (nfs, nfs4 or cifs)
</longdesc>
<shortdesc lang="en">
- NFS File System Type
+ File System Type
</shortdesc>
<content type="string"/>
</parameter>
@@ -215,7 +215,7 @@
[ -z "$OCF_RESKEY_fstype" ] && return 0
case $OCF_RESKEY_fstype in
- nfs|nfs4)
+ nfs|nfs4|cifs)
return 0
;;
*)
@@ -247,6 +247,9 @@
esac
case $OCF_RESKEY_fstype in
+ cifs)
+ continue
+ ;;
nfs|nfs4)
case $o in
#
@@ -374,7 +377,6 @@
return $FAIL
;;
esac
-
#
# Get the device
#
@@ -432,7 +434,16 @@
# Mount the NFS export
#
ocf_log debug "mount $fstype_option $mount_options $fullpath $mp"
- mount $fstype_option $mount_options $fullpath $mp
+
+ case $OCF_RESKEY_fstype in
+ nfs|nfs4)
+ mount -t $OCF_RESKEY_fstype $mount_options $host:$exp $mp
+ ;;
+ cifs)
+ mount -t $OCF_RESKEY_fstype $mount_options //$host/$exp $mp
+ ;;
+ esac
+
ret_val=$?
if [ $ret_val -ne 0 ]; then
ocf_log err "\
next reply other threads:[~2007-10-03 16:40 UTC|newest]
Thread overview: 6+ messages / expand[flat|nested] mbox.gz Atom feed top
2007-10-03 16:40 mgrac [this message]
-- strict thread matches above, loose matches on Subject: below --
2007-12-04 22:02 [Cluster-devel] cluster/rgmanager/src/resources netfs.sh lhh
2007-11-14 18:49 lhh
2007-10-03 17:01 lhh
2007-10-03 16:44 mgrac
2006-09-14 13:54 mgrac
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20071003164007.25115.qmail@sourceware.org \
--to=mgrac@sourceware.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -21,7 +21,7 @@
#
#
-# NFS file system mount/umount/etc. agent
+# NFS/CIFS file system mount/umount/etc. agent
#
LC_ALL=C
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.